struct VerifiedRoomRequest {
issuer: String,
room_key: SecretSlice<u8>,
config: RoomConfig,
origin: RequestOrigin,
}Expand description
Room credentials verified with the global auth key and a present issuer.
Accepts the Bearer and legacy jwt authorization schemes.
keySeed takes precedence over key and must be nonempty and decodable.
Query configuration and the proxy-aware RequestOrigin accompany the
resolved room key. Extraction does not create or reserve a room.
Errors
Extraction returns a [StatusCode] and records its room rejection counter:
400 Bad Request for invalid query parameters, absent key claims or failed
seed resolution or room key validation, 401 Unauthorized for missing or
unsupported authorization headers or failed JWT verification and
403 Forbidden for a missing issuer.
Query rejection takes precedence over credential rejection.
Fields
issuer: Stringroom_key: SecretSlice<u8>config: RoomConfigorigin: RequestOriginTrait Implementations
Sourceimpl Clone for VerifiedRoomRequest
impl Clone for VerifiedRoomRequest
Sourcefn clone(&self) -> VerifiedRoomRequest
fn clone(&self) -> VerifiedRoomRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifiedRoomRequest
impl Debug for VerifiedRoomRequest
Sourceimpl FromRequestParts<RuntimeState> for VerifiedRoomRequest
impl FromRequestParts<RuntimeState> for VerifiedRoomRequest
Sourcetype Rejection = StatusCode
type Rejection = StatusCode
If the extractor fails it’ll use this “rejection” type. A rejection is
a kind of error that can be converted into a response.
Sourceasync fn from_request_parts(
parts: &mut Parts,
state: &RuntimeState,
) -> Result<Self, Self::Rejection>
async fn from_request_parts( parts: &mut Parts, state: &RuntimeState, ) -> Result<Self, Self::Rejection>
Perform the extraction.